@@ -1,8 +1,8 @@
 /*---------------------------------------------------------------------------*\
-**$Author: antanas $
-**$Date: 2020-07-20 16:43:00 +0300 (Mon, 20 Jul 2020) $
-**$Revision: 8230 $
-**$URL: svn://www.crystallography.net/cod-tools/tags/v3.4.0/src/components/codcif/cif2_lexer.c $
+**$Author: andrius $
+**$Date: 2022-01-05 14:19:08 +0200 (Wed, 05 Jan 2022) $
+**$Revision: 9101 $
+**$URL: svn+ssh://www.crystallography.net/home/coder/svn-repositories/cod-tools/tags/v3.5.0/src/components/codcif/cif2_lexer.c $
 \*---------------------------------------------------------------------------*/
 
 /* exports: */
@@ -404,7 +404,8 @@ static int cif_lexer( FILE *in, cexception_t *ex )
             /* the character has to be checked to be equal to ';' in order
                to detect whether the lexer has arrived here after matching
                ';' or dropped through from ':': */
-            if( ch == ';' && ( prevchar == '\n' || prevchar == '\0' ) ) {
+            if( ch == ';' &&
+                ( prevchar == '\n' || prevchar == '\r' || prevchar == '\0' ) ) {
                 /* multi-line text field: */
                 advance_mark();
                 ssize_t textfield_start = cif_flex_current_line_number();
