@@ -1,8 +1,8 @@
 /*-------------------------------------------------------------------------*\
 * $Author: andrius $
-* $Date: 2019-12-27 15:30:51 +0200 (Fri, 27 Dec 2019) $ 
-* $Revision: 7629 $
-* $URL: svn://www.crystallography.net/cod-tools/tags/v3.4.0/src/components/codcif/cif_compiler.c $
+* $Date: 2022-01-04 19:15:46 +0200 (Tue, 04 Jan 2022) $ 
+* $Revision: 9091 $
+* $URL: svn+ssh://www.crystallography.net/home/coder/svn-repositories/cod-tools/tags/v3.5.0/src/components/codcif/cif_compiler.c $
 \*-------------------------------------------------------------------------*/
 
 /* exports: */
@@ -560,7 +560,7 @@ CIF *new_cif_from_cif_file( char *filename, cif_option_t co, cexception_t *ex )
         }
 
         /* Eat up the rest of the comment line */
-        while( ch != EOF && ch != '\t' && ch != '\n' ) {
+        while( ch != EOF && ch != '\r' && ch != '\n' ) {
             ch = getc( in );
         }
         
