@@ -1,8 +1,8 @@
 /*---------------------------------------------------------------------------*\
 **$Author: andrius $
-**$Date: 2020-08-18 14:16:58 +0300 (Tue, 18 Aug 2020) $
-**$Revision: 8359 $
-**$URL: svn://www.crystallography.net/cod-tools/tags/v3.4.0/src/components/codcif/cif_lex_buffer.c $
+**$Date: 2022-01-03 14:06:49 +0200 (Mon, 03 Jan 2022) $
+**$Revision: 9081 $
+**$URL: svn+ssh://www.crystallography.net/home/coder/svn-repositories/cod-tools/tags/v3.5.0/src/components/codcif/cif_lex_buffer.c $
 \*---------------------------------------------------------------------------*/
 
 /* exports: */
@@ -58,8 +58,16 @@ void cif_lexer_cleanup( void )
     length = 0;
 
     if( current_line ) freex( current_line );
-    current_line = NULL;
     current_line_length = 0;
+
+    if( thisTokenLine && thisTokenLine != current_line ) freex( thisTokenLine );
+    if( lastTokenLine &&
+        lastTokenLine != current_line &&
+        lastTokenLine != thisTokenLine ) freex( lastTokenLine );
+
+    current_line = NULL;
+    thisTokenLine = NULL;
+    lastTokenLine = NULL;
 }
 
 int cif_lexer_set_report_long_lines( int flag )
