@@ -2,7 +2,7 @@
 **$Author: andrius $
 **$Date: 2021-05-26 08:15:47 +0300 (Wed, 26 May 2021) $ 
 **$Revision: 8796 $
-**$URL: svn://www.crystallography.net/cod-tools/tags/v3.4.0/src/components/codcif/programs/cif_list_tags.c $
+**$URL: svn+ssh://www.crystallography.net/home/coder/svn-repositories/cod-tools/tags/v3.5.0/src/components/codcif/programs/cif_list_tags.c $
 \*---------------------------------------------------------------------------*/
 
 /* uses: */
@@ -17,7 +17,7 @@
 #include <allocx.h>
 #include <version.h>
 
-static char *source_URL = "$URL: svn://www.crystallography.net/cod-tools/tags/v3.4.0/src/components/codcif/programs/cif_list_tags.c $";
+static char *source_URL = "$URL: svn+ssh://www.crystallography.net/home/coder/svn-repositories/cod-tools/tags/v3.5.0/src/components/codcif/programs/cif_list_tags.c $";
 
 static char *usage_text[2] = {
 
