@@ -2,7 +2,7 @@
 **$Author: antanas $
 **$Date: 2020-07-20 16:43:00 +0300 (Mon, 20 Jul 2020) $ 
 **$Revision: 8230 $
-**$URL: svn://www.crystallography.net/cod-tools/tags/v3.4.0/src/components/codcif/programs/cifparse.c $
+**$URL: svn+ssh://www.crystallography.net/home/coder/svn-repositories/cod-tools/tags/v3.5.0/src/components/codcif/programs/cifparse.c $
 \*---------------------------------------------------------------------------*/
 
 /* uses: */
@@ -22,7 +22,7 @@
 #include <ctype.h>
 #include <version.h>
 
-static char *source_URL = "$URL: svn://www.crystallography.net/cod-tools/tags/v3.4.0/src/components/codcif/programs/cifparse.c $";
+static char *source_URL = "$URL: svn+ssh://www.crystallography.net/home/coder/svn-repositories/cod-tools/tags/v3.5.0/src/components/codcif/programs/cifparse.c $";
 
 static char *usage_text[2] = {
 
